<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sv">
<context>
    <name>LogForm</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Machine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User</source>
        <translation>Användare</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Tjänst</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Öppna fil</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
</context>
<context>
    <name>MainWindows</name>
    <message>
        <source>Show CIFS/SMB activities</source>
        <translation>Visa CIFS/SMB aktiviteter</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Konfigurera</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Minimera</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Återställ</translation>
    </message>
    <message>
        <source>Thanks to:</source>
        <translation>Tack till:</translation>
    </message>
    <message>
        <source>This program is licensed to you under the terms of the GNU General Public License version 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Sök text</translation>
    </message>
    <message>
        <source>Text not found.</source>
        <translation>Texten hittades inte.</translation>
    </message>
    <message>
        <source>User %1 has opened share %2 (%3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User %1 has opened file %2 (%3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CIFS/SMB activities</source>
        <translation>CIFS/SMB aktiviteter</translation>
    </message>
    <message>
        <source>Message to send</source>
        <translation>Medelande att skicka</translation>
    </message>
    <message>
        <source>Message to send to %1:</source>
        <translation>Medelande att skicka till %1:</translation>
    </message>
    <message>
        <source>Do you really want to disconnect user %1 ?</source>
        <translation>Vill du verkligen koppla ner användare %1?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Ja</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nej</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Egenskaper</translation>
    </message>
    <message>
        <source>Send out message to all users</source>
        <translation>Skicka ut medelande till alla användare</translation>
    </message>
    <message>
        <source>Send out message to</source>
        <translation>Skicka ut medelande till</translation>
    </message>
    <message>
        <source>Disconnect user</source>
        <translation>Koppla ner användaren</translation>
    </message>
    <message>
        <source>Update is available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A new release of %1 is available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can download it here: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <source>Configure</source>
        <translation>Konfigurera</translation>
    </message>
    <message>
        <source>Autoconnect</source>
        <translation>Auto anslut</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Default host address:&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Default Username:&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host Address</source>
        <translation>Värdadress</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Interval:&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Username (default :  username = root)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log SMB/CIFS activities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status notification messages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notifications and log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Limit log:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation>dagar</translation>
    </message>
    <message>
        <source>Iconize QtSmbstatus in system tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smbstatus</source>
        <translation>Smbstatus</translation>
    </message>
    <message>
        <source>Interval between smbstatus requests in seconds, (interval &gt; 2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show hidden shares (share$)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show hidden shares</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Anslutning</translation>
    </message>
    <message>
        <source>Autoconnect on qtsmbstatus startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show activities in &quot;balloon messages&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Misc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically Check for updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A new release is available</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>form_smbstatus</name>
    <message>
        <source>qtsmbstatus</source>
        <translation>qtsmbstatus</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hjälp</translation>
    </message>
    <message>
        <source>&amp;About QtSmbstatus</source>
        <translation>&amp;Om QrSmbstatus</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Om &amp;Qt</translation>
    </message>
    <message>
        <source>Connect/Disconnect</source>
        <translation>Anslut/Koppla ner</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Värd:</translation>
    </message>
    <message>
        <source>&amp;Configure client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>&amp;Sök</translation>
    </message>
    <message>
        <source>&amp;Machine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;User</source>
        <translation>&amp;Användare</translation>
    </message>
    <message>
        <source>Share &amp;open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Locked file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Nästa</translation>
    </message>
    <message>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <source>&amp;Find text</source>
        <translation>&amp;Sök text</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fil</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>Om Qt</translation>
    </message>
    <message>
        <source>Configure QtSmbstatus client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search machine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search share open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search file open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Nästa</translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Sök text</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Avsluta</translation>
    </message>
    <message>
        <source>Quit QtSmbstatus</source>
        <translation>Avsluta QtSmbstatus</translation>
    </message>
    <message>
        <source>Co&amp;nnect</source>
        <translation>A&amp;nslut</translation>
    </message>
    <message>
        <source>&amp;Show CIFS/SMB activities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About QtSmbstatus</source>
        <translation>Om QtSmbstatus</translation>
    </message>
</context>
<context>
    <name>logform</name>
    <message>
        <source>View Activities</source>
        <translation>Visa aktiviteter</translation>
    </message>
    <message>
        <source>View/hide shares</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View/hide files</source>
        <translation>Visa/Göm filer</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <source>Save log</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>login_dialog</name>
    <message>
        <source>login</source>
        <translation>logga in</translation>
    </message>
    <message>
        <source>exit</source>
        <translation>avsluta</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Användarnamn</translation>
    </message>
    <message>
        <source>root</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Lösenord</translation>
    </message>
    <message>
        <source>Connect to qtsmbstatus server</source>
        <translation>Anslut till qtsmbstatus server</translation>
    </message>
</context>
<context>
    <name>main_windows</name>
    <message>
        <source>Connect</source>
        <translation>Anslut</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Koppla ner</translation>
    </message>
    <message>
        <source>Invalid login or password !</source>
        <translation>Ogiltigt användarnamn eller lösenord!</translation>
    </message>
    <message>
        <source>Connection in progress on %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connected to host</source>
        <translation>Ansluten till värd</translation>
    </message>
    <message>
        <source>Connection closed</source>
        <translation>Anslutning stängd</translation>
    </message>
    <message>
        <source>The server certificate doesn&apos;t contain valid data or expired !</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The authenticity of host &apos;%1&apos; can&apos;t be established.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to continue connecting ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SHA1 Fingerprint: %1.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
